@@ -14,7 +14,8 @@ from terraform_compliance.common.helper import (
     dict_merge,
     is_list_of_dict,
     is_key_exist,
-    transform_asg_style_tags
+    transform_asg_style_tags,
+    python_version_check
 )
 
 
@@ -89,6 +90,13 @@ class TestHelperFunctions(TestCase):
 
         self.assertEqual(seek_key_in_dict(dictionary, search_key), expected)
 
+    def test_seek_in_dict_for_root_and_non_root_values(self):
+        dictionary = dict(a=dict(b=dict(something=dict(test=[]))), something=["b"])
+        search_key = "something"
+        expected = [{'something':{'test': []}}, {'something':['b']}]
+
+        self.assertEqual(seek_key_in_dict(dictionary, search_key), expected)
+
     def test_seek_in_dict_finding_values_in_non_dicts_on_root(self):
         dictionary = 'something_else'
         search_key = 'something_else'
@@ -268,3 +276,6 @@ class TestHelperFunctions(TestCase):
         resource_list = 'abc'
         output = transform_asg_style_tags(resource_list)
         self.assertEqual(output, 'abc')
+
+    def test_python_version_check_success(self):
+        self.assertEqual(python_version_check(), 1)
